import 'dart:convert';
import 'dart:io';

extension GracefulFile on File {
  createIfNotExists({bool recursive = true}) async {
    if (!await this.exists()) {
      return await this.create(recursive: recursive);
    }
  }

  createIfNotExistsSync({bool recursive = true}) {
    if (this.existsSync()) return;
    this.createSync(recursive: recursive);
  }

  String maybeReadAsStringSync({Encoding encoding = utf8}) {
    if (this.existsSync()) {
      return this.readAsStringSync(encoding: encoding);
    }

    return '';
  }

  Future<String> maybeReadAsString({Encoding encoding = utf8}) async {
    if (await this.exists()) {
      return this.readAsString(encoding: encoding);
    }

    return '';
  }
}
